==> V01.76.zip: tweet_live-V01.76/web/2011-2012-museo-interfaces/config.php <==
<?php
$config = array(
   	'hashtag'    => '#museoweb',
   	'date'   	 => '15.05.2012',
   	'heure'   	 => '17h00-20h00',
   	'place'   	 => 'Centre Pompidou (Paris)',
   	'duration'   => '',

   	'title' 	 => "Muséologie, muséographie et nouvelles formes d’adresse au public",
						
   	'abstract'   => "«&nbsp;<b>Des interfaces innovantes tirant parti des métadonnées</b>&nbsp;» <br/> 15 / 05 / 2012 de 17h00 à 20h00 @ Centre Pompidou (Paris)",

   	'description'=> "<p><b>Des interfaces innovantes tirant parti des métadonnées.</b> (le&nbsp;15/05/2012)</p>
   	<p>Les métadonnées sont la base de départ pour la conception des interfaces pour l’indexation, la recherche, la navigation et la représentation. Comment peuvent elles aller jusqu’à modifier une stratégie de collecte ?</p>
<ul>
    <li><b>Jean Daniel Fekete</b> – INRIA/Aviz</li>
    <li><b>Yves Armel Martin</b> – Erasme</li>
    <li><b>Carlo d’Asara Biondo</b> – Google</li>
</ul>
<p>Coup de projecteur :</p>
<ul>
    <li><b>Wiki loves monuments</b></li>
</ul>",

   	'link' 		 => 'http://www.iri.centrepompidou.fr/evenement/museologie-museographie-et-nouvelles-formes-dadresse-au-public/?lang=fr_fr',
   	'islive'     => true,
   	'keywords'   => 'muséographie, muséologie, interfaces, métadonnées, innovation, recherche, navigation, représentation',
   	'rep' 		 => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.culture.gouv.fr/'
class='footerLink' target='_blank'> Ministère de la Culture et communication </a>
|  <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
IRI  </a>",

    'client_visual' => "images/big_visuel_museo_2011_fr.png", // 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => "images/slide4_museo_fr.png", // 606 × 282 pixels
    
  	'archive_img' => "images/museo-2011.jpg", // 270 × 150 pixels

 	'archive_title' => "Muséologie 2011 - Des interfaces innovantes tirant parti des métadonnées",
 	'archive_description' => "par <a href=\"http://www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> au Centre Pompidou<br/> le mardi 15 mai 2012 | 17:00 - 20:00",

    // After the event
	'metadata'		=> "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/321ae0b0-ff2c-11e0-95c2-00145ea49a02",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 500,
);

==> V01.93.zip: tweet_live-V01.93/web/2011-2012-museo-interfaces/config.php <==
<?php
$config = array(
   	'hashtag'    => '#museoweb',
   	'date'   	 => '15.05.2012',
   	'heure'   	 => '17h00-20h00',
   	'place'   	 => 'Centre Pompidou (Paris)',
   	'duration'   => '',

   	'title' 	 => "Muséologie, muséographie et nouvelles formes d’adresse au public",
						
   	'abstract'   => "«&nbsp;<b>Des interfaces innovantes tirant parti des métadonnées</b>&nbsp;» <br/> 15 / 05 / 2012 de 17h00 à 20h00 @ Centre Pompidou (Paris)",

   	'description'=> "<p><b>Des interfaces innovantes tirant parti des métadonnées.</b> (le&nbsp;15/05/2012)</p>
   	<p>Les métadonnées sont la base de départ pour la conception des interfaces pour l’indexation, la recherche, la navigation et la représentation. Comment peuvent elles aller jusqu’à modifier une stratégie de collecte ?</p>
<ul>
    <li><b>Jean Daniel Fekete</b> – INRIA/Aviz</li>
    <li><b>Yves Armel Martin</b> – Erasme</li>
    <li><b>David Assouline</b> - Google Art Project</li>
</ul>
<p>Coup de projecteur :</p>
<ul>
    <li><b>Wiki loves monuments</b></li>
</ul>",

   	'link' 		 => 'http://www.iri.centrepompidou.fr/evenement/museologie-museographie-et-nouvelles-formes-dadresse-au-public/?lang=fr_fr',
   	'islive'     => true,
   	'keywords'   => 'muséographie, muséologie, interfaces, métadonnées, innovation, recherche, navigation, représentation',
   	'rep' 		 => basename('__DIR__'),
   	'partenaires'=> "<a href='http://www.culture.gouv.fr/'
class='footerLink' target='_blank'> Ministère de la Culture et communication </a>
|  <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
IRI  </a>",

    'client_visual' => "images/big_visuel_museo_2011_fr.png", // 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => "images/slide4_museo_fr.png", // 606 × 282 pixels
    
  	'archive_img' => "images/museo-2011.jpg", // 270 × 150 pixels

 	'archive_title' => "Muséologie 2011 - Des interfaces innovantes tirant parti des métadonnées",
 	'archive_description' => "par <a href=\"http://www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> au Centre Pompidou<br/> le mardi 15 mai 2012 | 17:00 - 20:00",

    // After the event
	'metadata'		=> "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/321ae0b0-ff2c-11e0-95c2-00145ea49a02",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 500,
    'pad_url'       => 'http://pads.iri-research.org/p/museo-interfaces?showControls=true&showChat=true&showLineNumbers=true&useMonospaceFont=false'
);
